@@ -543,6 +543,8 @@ def local_path_generate(folder_name: str, file_name: str = "",
         file_name = file_name + str(random.randint(10000, 99999))
         file_name = file_name + suffix
     dir = os.path.abspath(folder_name)
+    for k in FORBIDDEN_LIST:
+        file_name = file_name.replace(k, "")
     work_path = os.path.join(dir, file_name)
     return work_path
 
@@ -590,6 +592,22 @@ def cookieString2CookieJar(cookie: str = "") -> RequestsCookieJar:
     return cookie_jar
 
 
+def deleteSpecialCharFromHtmlElement(html: str = "", sep: str = " ") -> str:
+    names = []
+    flag = True
+    for k in list(html):
+        if k == "<":
+            flag = False
+            continue
+        if k == ">":
+            flag = True
+            names.append(sep)
+            continue
+        if flag:
+            names.append(k)
+    return "".join(names)
+
+
 class NoProxyException(Exception):
     def __init__(self, *args: object) -> None:
         super().__init__(*args)
