@@ -4,15 +4,18 @@ import io
 import json
 import sys
 import threading
+import time
 import urllib
 from typing import Optional, Callable, Any, Iterable, Mapping
+
+import requests
 from httpcore import SyncHTTPProxy
 import PyPDF2
 from PyPDF2 import PdfFileWriter, PdfFileReader
 import pdfplumber
 from googletrans import Translator
 from pdf2docx import Converter
-
+import execjs
 from crawler_util import *
 
 
@@ -457,9 +460,10 @@ def getSomePagesFromOnePDF(path: str, out_path: str, page_range: tuple or list,
 
 
 def getSomePagesFromFileOrDirectory(path: str, page_range: tuple or list, out_directory: str = "",
-                                    need_log: bool = True, timeout: float = 20) -> None:
+                                    need_log: bool = True, timeout: float = 20, need_bar: bool = True) -> None:
     """
     从给定的文件夹或者文件路径中，截取指定的页面，保存到给定输出目录中
+    :param need_bar: 是否需要使用进度条代替日志显示，此项为True时，覆盖need_log参数
     :param path: 文件夹或者文件路径
     :param page_range: 截取的范围，如果是元组，则连续截取[a,b]的页面，注意从0开始，如果是列表，
     则按照列表给出的信息截取
@@ -471,19 +475,30 @@ def getSomePagesFromFileOrDirectory(path: str, page_range: tuple or list, out_di
 
     count = 0
     sum = 0
+    need_log = need_log if not need_bar else False
     if os.path.isfile(path):
+        p = process_bar(total=1, desc="文件截取进度：", final_prompt="文件截取完成")
+        p.process(0, 1, 1)
         sum = 1
-        if getSomePagesFromOnePDF(path, local_path_generate(out_directory), page_range, need_log):
+        if getSomePagesFromOnePDF(path, local_path_generate(out_directory, need_log=need_log), page_range, need_log):
             count = count + 1
+            p.process(1, 1, 1)
     else:
         files = getAllFiles(path)
+        total = 0
+        for f in files:
+            if f.endswith(".pdf"):
+                total = total + 1
+        p = process_bar(total=total, desc="文件截取进度：", final_prompt="文件截取完成")
+        p.process(0, 1, total)
         for k in files:
             if not k.endswith(".pdf"):
                 log(string="文件{}不是PDF文件".format(k), print_file=sys.stderr)
                 continue
             sum = sum + 1
-            if getSomePagesFromOnePDF(k, local_path_generate(out_directory), page_range, need_log, timeout):
+            if getSomePagesFromOnePDF(k, local_path_generate(out_directory, need_log=need_log), page_range, need_log, timeout):
                 count = count + 1
+                p.process(count, 1, total)
     if need_log:
         log("总计待截取文件：{}，成功：{}".format(str(sum), str(count)))
 
@@ -491,7 +506,6 @@ def getSomePagesFromFileOrDirectory(path: str, page_range: tuple or list, out_di
 def cooperatePdfWithLimit(files: list, page_range: tuple or list = None, out_path: str = "",
                           need_log: bool = True, timeout: float = -1, group_id: str = "",
                           need_group: bool = True) -> bool:
-
     """
     合并列表的PDF文件到指定目录
     :param files: 文件列表
@@ -599,9 +613,10 @@ def cooperatePdfWithLimit(files: list, page_range: tuple or list = None, out_pat
 
 def cooperatePdf(path: str, page_range: tuple or list = None, out_path: str = "",
                  need_log: bool = True, timeout: float = -1, group_number: int = 50,
-                 need_group: bool = True) -> None:
+                 need_group: bool = True, need_processbar: bool = True) -> None:
     """
     合并文件夹中所有的PDF文件到指定目录
+    :param need_processbar: 是否需要使用进度条代替日志显示，此项为True时，覆盖need_log参数
     :param path: 文件夹路径
     :param page_range: 合并的页码范围，如果是元组，则连续截取[a,b]的页面，注意从0开始，如果是列表，
     则按照列表给出的信息截取，如果此项值不给定，则默认全部合并
@@ -613,6 +628,7 @@ def cooperatePdf(path: str, page_range: tuple or list = None, out_path: str = ""
     :param need_group: 是否需要分组合并
     :return:
     """
+    need_log = need_log if not need_processbar else False
     if len(path) == 0:
         log("给定路径为空，合并结束：{}".format(path))
     elif os.path.isfile(path):
@@ -621,6 +637,9 @@ def cooperatePdf(path: str, page_range: tuple or list = None, out_path: str = ""
         page_range = []
     files = getAllFiles(path)
     if need_group:
+        if need_processbar:
+            p = process_bar(desc="文件合并进度：", total=len(files), final_prompt="文件合并完成")
+            p.process(0, group_number, len(files))
         i: int = 0
         group_id: int = 0
         file_group = []
@@ -629,10 +648,155 @@ def cooperatePdf(path: str, page_range: tuple or list = None, out_path: str = ""
                 cooperatePdfWithLimit(file_group, page_range, out_path, need_log, timeout, str(group_id))
                 group_id = group_id + 1
                 file_group.clear()
+                if need_processbar:
+                    p.process(0, group_number, len(files))
             file_group.append(files[i])
             i = i + 1
     else:
+        if need_processbar:
+            p = process_bar(desc="文件合并进度：", total=len(files), final_prompt="文件合并完成")
+            p.process(0, group_number, len(files))
         cooperatePdfWithLimit(files, page_range, out_path, need_log, timeout, need_group=False)
+        if need_processbar:
+            p.process(0, len(files), len(files))
+
+
+class Py4Js:
+
+    def __init__(self):
+        self.ctx = execjs.compile(""" 
+        function TL(a) { 
+        var k = ""; 
+        var b = 406644; 
+        var b1 = 3293161072; 
+
+        var jd = "."; 
+        var $b = "+-a^+6"; 
+        var Zb = "+-3^+b+-f"; 
+
+        for (var e = [], f = 0, g = 0; g < a.length; g++) { 
+            var m = a.charCodeAt(g); 
+            128 > m ? e[f++] = m : (2048 > m ? e[f++] = m >> 6 | 192 : (55296 == (m & 64512) && g + 1 < a.length && 56320 == (a.charCodeAt(g + 1) & 64512) ? (m = 65536 + ((m & 1023) << 10) + (a.charCodeAt(++g) & 1023), 
+            e[f++] = m >> 18 | 240, 
+            e[f++] = m >> 12 & 63 | 128) : e[f++] = m >> 12 | 224, 
+            e[f++] = m >> 6 & 63 | 128), 
+            e[f++] = m & 63 | 128) 
+        } 
+        a = b; 
+        for (f = 0; f < e.length; f++) a += e[f], 
+        a = RL(a, $b); 
+        a = RL(a, Zb); 
+        a ^= b1 || 0; 
+        0 > a && (a = (a & 2147483647) + 2147483648); 
+        a %= 1E6; 
+        return a.toString() + jd + (a ^ b) 
+    }; 
+
+    function RL(a, b) { 
+        var t = "a"; 
+        var Yb = "+"; 
+        for (var c = 0; c < b.length - 2; c += 3) { 
+            var d = b.charAt(c + 2), 
+            d = d >= t ? d.charCodeAt(0) - 87 : Number(d), 
+            d = b.charAt(c + 1) == Yb ? a >>> d: a << d; 
+            a = b.charAt(c) == Yb ? a + d & 4294967295 : a ^ d 
+        } 
+        return a 
+    } 
+    """)
+
+    def getTk(self, text):
+        return self.ctx.call("TL", text)
+
+
+def google_trans_final(content: str = "", sl: str = AUTO, tl: str = EN,
+                       proxy: str = "127.0.0.1:1080", reporthook: Callable[[], None] = None,
+                       total: int = 0, need_log: bool = True, cookie: str = "", token: str = "") -> str:
+    """
+        网页版谷歌翻译，需要提供可以访问谷歌的代理
+        :param token: not used
+        :param cookie: not used
+        :param total: 翻译总数量
+        :param content: 待翻译内容
+        :param sl: 源语言
+        :param tl: 目标语言
+        :param proxy: 代理
+        :param reporthook: 完成翻译后使用的函数，这里默认使用内置进度条
+        :param need_log: 是否需要打印日志，翻译结果等
+        :return: 翻译后的文本
+        """
+    js = Py4Js()
+    tk = js.getTk(content)
+    url = "http://translate.google.com/translate_a/single?client=t"
+    url = url + "&sl=" + sl + "&tl=" + tl
+    url = url + ("&hl=en&dt=at&dt=bd&dt=ex&dt=ld&dt=md&dt=qca&dt=rw")
+    url = url + ("&dt=rm&dt=ss&dt=t&ie=UTF-8&oe=UTF-8&clearbtn=1&otf=1")
+    url = url + ("&pc=1&srcrom=0&ssel=0&tsel=0&kc=2&tk=%s&q=%s" % (tk, content))
+    html = random_proxy_header_access(url=url, proxy=proxy, require_proxy=True,
+                                      random_proxy=False, return_type="object", need_log=False)
+    ret = ''
+    try:
+        trans = html.json()[0]
+        for i in range(len(trans)):
+            line = trans[i][0]
+            if line is not None:
+                ret += trans[i][0]
+        if reporthook:
+            reporthook(0, 1000, total)
+    except Exception as e:
+        if need_log:
+            log("翻译错误：{}".format(e), print_file=sys.stderr)
+    return ret
+
+
+def translate_web(content: str = "", sl: str = AUTO, tl: str = EN,
+                  proxy: str = "127.0.0.1:1080", sleep_time: float = 2,
+                  need_log: bool = True, translate_method: Callable[[], str] = None,
+                  cookie: str = "", token: str = ""):
+    """
+    网页版翻译接口，可以通过translate_method传入需要调用的翻译接口，如果为谷歌翻译需要提供可以访问谷歌的代理
+    :param token: token
+    :param cookie: cookie
+    :param translate_method: 需要调用的翻译方法，需要接受的参数包括：
+    content, sl, tl, proxy, total, reporthook, need_log, cookie, token
+    :param content: 待翻译内容
+    :param sl: 源语言
+    :param tl: 目标语言
+    :param proxy: 代理
+    :param sleep_time: 每次访问翻译睡眠时间
+    :param need_log: 是否需要打印日志，翻译结果等
+    :return: 翻译后的文本
+    """
+    res_trans = ""
+    count = 0
+    sum = len(content)
+    p = process_bar(desc="翻译进度：", final_prompt="翻译完成", total=sum)
+    p.process(0, 1000, sum)
+    if len(content) > 1000:
+        while len(content) > 1000:
+            temp = content[0:999]
+            content = content[1000:]
+            temp_trans = translate_method(content=temp, sl=sl, tl=tl, proxy=proxy, total=sum,
+                                          reporthook=p.process, need_log=need_log, cookie=cookie,
+                                          token=token)
+            res_trans = res_trans + temp_trans
+            count = count + 1
+            time.sleep(sleep_time)
+        temp_trans = translate_method(content=content, sl=sl, tl=tl, proxy=proxy, total=sum,
+                                      need_log=need_log, cookie=cookie, reporthook=p.process,
+                                      token=token)
+        res_trans += temp_trans
+        if need_log:
+            log(res_trans)
+        return res_trans
+    else:
+        time.sleep(sleep_time)
+        res_trans = translate_method(content=content, sl=sl, tl=tl, proxy=proxy, total=sum,
+                                     need_log=need_log, cookie=cookie, reporthook=p.process,
+                                     token=token)
+        if need_log:
+            log(res_trans)
+        return res_trans
 
 
 if __name__ == "__main__":
